summaryrefslogtreecommitdiffstats
path: root/Source/cmCableInstantiateCommand.h
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
committerBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
commitd0a8794746f6de026f1c69652cd09caf8be9cfab (patch)
tree2143ad59bf1fef6f340dd7fb199f556eadff0ef4 /Source/cmCableInstantiateCommand.h
parente5e2a57bfbf1aac2c265e894db82d2b2d5673084 (diff)
downloadCMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.zip
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.gz
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.bz2
ENH: CABIL -> CABLE rename.
Diffstat (limited to 'Source/cmCableInstantiateCommand.h')
-rw-r--r--Source/cmCableInstantiateCommand.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/Source/cmCableInstantiateCommand.h b/Source/cmCableInstantiateCommand.h
index 1bb3722..d61eb77 100644
--- a/Source/cmCableInstantiateCommand.h
+++ b/Source/cmCableInstantiateCommand.h
@@ -13,20 +13,20 @@
See COPYRIGHT.txt for copyright details.
=========================================================================*/
-#ifndef cmCabilInstantiateCommand_h
-#define cmCabilInstantiateCommand_h
+#ifndef cmCableInstantiateCommand_h
+#define cmCableInstantiateCommand_h
#include "cmStandardIncludes.h"
-#include "cmCabilCommand.h"
+#include "cmCableCommand.h"
-/** \class cmCabilInstantiateCommand
+/** \class cmCableInstantiateCommand
* \brief Define a command that generates a rule for explicit template
* instantiations.
*
* cmCabilInstantiateCommand is used to generate a rule in a CABIL
* configuration file to create explicit template instantiations.
*/
-class cmCabilInstantiateCommand : public cmCabilCommand
+class cmCableInstantiateCommand : public cmCableCommand
{
public:
/**
@@ -34,7 +34,7 @@ public:
*/
virtual cmCommand* Clone()
{
- return new cmCabilInstantiateCommand;
+ return new cmCableInstantiateCommand;
}
/**
@@ -58,14 +58,14 @@ public:
/**
* The name of the command as specified in CMakeList.txt.
*/
- virtual const char* GetName() { return "CABIL_INSTANTIATE";}
+ virtual const char* GetName() { return "CABLE_INSTANTIATE";}
/**
* Succinct documentation.
*/
virtual const char* GetTerseDocumentation()
{
- return "Define CABIL InstantiationSet.";
+ return "Define CABLE InstantiationSet.";
}
/**
@@ -74,22 +74,22 @@ public:
virtual const char* GetFullDocumentation()
{
return
- "CABIL_INSTANTIATE(cabil_config_file member1 member2 ...)\n"
- "Generates an InstantiationSet in the CABIL configuration. It is\n"
+ "CABLE_INSTANTIATE(cable_config_file member1 member2 ...)\n"
+ "Generates an InstantiationSet in the CABLE configuration. It is\n"
"assumed that all members of the set are explicit instantiations of\n"
"template non-classes (functions, operators, etc).";
}
virtual void WriteConfiguration(std::ostream&) const;
- cmTypeMacro(cmCabilInstantiateCommand, cmCabilCommand);
+ cmTypeMacro(cmCableInstantiateCommand, cmCableCommand);
protected:
typedef std::vector<std::string> Elements;
/**
* The output file to which to write the configuration.
*/
- cmCabilData::OutputFile* m_OutputFile;
+ cmCableData::OutputFile* m_OutputFile;
/**
* The elements describing the set of instantiations.
@@ -13,20 +13,20 @@
* instantiations.
*
- * cmCabilInstantiateCommand is used to generate a rule in a CABIL
+ * cmCableInstantiateCommand is used to generate a rule in a CABLE
* configuration file to create explicit template instantiations.
*/